==> haskell-binary-orphans-1.0.1-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.1
visibility:           public
id:                   binary-orphans-1.0.1-DORwW9xpaez4jnxsq3XN4q
key:                  binary-orphans-1.0.1-DORwW9xpaez4jnxsq3XN4q
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  46b672e4dd61436e155aefa85aad8c4f
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/binary-orphans-1.0.1
hs-libraries:         HSbinary-orphans-1.0.1-DORwW9xpaez4jnxsq3XN4q
depends:              base-4.15.0.0 binary-0.8.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-1.0.1-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.1
visibility:           public
id:                   binary-orphans-1.0.1-A9pYUIBwXpP132pcqRa1FJ
key:                  binary-orphans-1.0.1-A9pYUIBwXpP132pcqRa1FJ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  9f8cf64993a05cae6536d9674c06bb40
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/binary-orphans-1.0.1
hs-libraries:         HSbinary-orphans-1.0.1-A9pYUIBwXpP132pcqRa1FJ
depends:              base-4.15.0.0 binary-0.8.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
